/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties.query.xpath;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.resource.i18n.MessagesImpl;
import org.apache.ws.resource.properties.faults.UnknownQueryExpressionDialectFaultException;
import org.apache.ws.resource.properties.query.InvalidQueryExpressionException;
import org.apache.ws.resource.properties.query.QueryConstants;
import org.apache.ws.resource.properties.query.QueryExpression;
import org.apache.ws.resource.properties.query.UnknownQueryExpressionDialectException;
import org.apache.ws.util.i18n.Messages;
import org.apache.ws.util.xml.NamespaceContext;

/**
 * LOG-DONE
 * An XPath expression
 *
 * @author Ian P. Springer
 */
public class XPathExpression
{
   private static final Log LOG = LogFactory.getLog( XPathExpression.class );
   public static final Messages MSG = MessagesImpl.getInstance();

   private String  m_value;
   private NamespaceContext m_nsContext;

   /**
    * Creates a new {@link XPathExpression} object.
    *
    * @param queryExpr DOCUMENT_ME
    *
    * @throws UnknownQueryExpressionDialectFaultException
    *          DOCUMENT_ME
    */
   public XPathExpression( QueryExpression queryExpr )
   throws InvalidQueryExpressionException, 
          UnknownQueryExpressionDialectException
   {
      if ( !queryExpr.getDialect(  ).equals( QueryConstants.DIALECT_URI__XPATH1_0 ) )
      {
         throw new UnknownQueryExpressionDialectException( queryExpr.getDialect(  ) );
      }
      if ( queryExpr.getContent(  ) == null || ! ( queryExpr.getContent(  ) instanceof String ) )
      {
         throw new InvalidQueryExpressionException( queryExpr );
      }
      m_value = ((String) queryExpr.getContent()).trim();
      if ( m_value.length() == 0 )
      {
         throw new InvalidQueryExpressionException( queryExpr );
      }
      m_nsContext = queryExpr.getNamespaceContext();

      if(LOG.isDebugEnabled())
      {
        LOG.debug(MSG.getMessage( Keys.CONSTR_XPATH_EXPR,toString()));
      }
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public NamespaceContext getNamespaceContext(  )
   {
      return m_nsContext;
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String getValue(  )
   {
      return m_value;
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String toString(  )
   {
      return new ToStringBuilder( this ).append( MSG.getMessage( Keys.VALUE), m_value )
                                        .toString(  );
   }
}