/*=============================================================================*
 *  Copyright 2005 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.util.xml.impl;

import org.apache.ws.util.xml.NamespaceContext;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * A namespace context based on a DOM {@link Node}.
 */
public class DomNamespaceContext implements NamespaceContext
{

    private static final String XMLNS_XML =
            "http://www.w3.org/XML/1998/namespace";

    private Node m_context;

    public DomNamespaceContext( Node context )
    {
        m_context = context;
    }

    /**
     * Snarfed from Xalan's <code>org.apache.xml.utils.PrefixResolverDefault</code> class.      
     */
    public String getNamespaceURI( String prefix )
    {
        String namespaceURI = null;
        if ( prefix.equals( "xml" ) )
        {
            namespaceURI = XMLNS_XML;
        }
        else
        {
            Node parent = m_context;
            int type;
            while ( ( null != parent ) && ( null == namespaceURI )
                    && ( ( ( type = parent.getNodeType() ) == Node.ELEMENT_NODE )
                    || ( type == Node.ENTITY_REFERENCE_NODE ) ) )
            {
                if ( type == Node.ELEMENT_NODE )
                {
                    NamedNodeMap attribMap = parent.getAttributes();
                    for ( int i = 0; i < attribMap.getLength(); i++ )
                    {
                        Node attrib = attribMap.item( i );
                        String attribName = attrib.getNodeName();
                        boolean isPrefix = attribName.startsWith( "xmlns:" );
                        if ( isPrefix || attribName.equals( "xmlns" ) )
                        {
                            int index = attribName.indexOf( ':' );
                            String declaredPrefix = isPrefix ? attribName.substring( index + 1 ) : "";
                            if ( declaredPrefix.equals( prefix ) )
                            {
                                namespaceURI = attrib.getNodeValue();
                                break;
                            }
                        }
                    }
                }
                parent = parent.getParentNode();
            }
        }
        return namespaceURI;
    }

    public String getPrefix( String namespaceURI )
    {
        // TODO
        return null;
    }

    public Iterator getPrefixes( String namespaceURI )
    {
        List prefixes = new ArrayList();
        // TODO
        return prefixes.iterator();
    }

    public Node getContextNode()
    {
        return m_context;
    }

}
